import connection from "./connection";
import { DataTypeOIDs } from "postgrejs";

const deleteVehiclePositionsPrepared = await connection.prepare(
  `DELETE FROM "vehiclePosition"
     WHERE received < $1;`,
  {
    paramTypes: [DataTypeOIDs.timestamptz],
  },
);
const deleteDepartureStatusPrepared = await connection.prepare(
  `DELETE FROM "departureStatus"
     WHERE received < $1;`,
  {
    paramTypes: [DataTypeOIDs.timestamptz],
  },
);
async function vehiclePositions() {
  const twoMinutesAgo = new Date(Date.now() - 2 * 60 * 1000);
  const result = await deleteVehiclePositionsPrepared.execute({
    params: [twoMinutesAgo],
  });
  console.log("deleted", result.rowsAffected, "vehiclePositions");
}

async function departureStatus() {
  const ninetyMinutesAgo = new Date(Date.now() - 90 * 60 * 1000);
  const result = await deleteDepartureStatusPrepared.execute({
    params: [ninetyMinutesAgo],
  });
  console.log("deleted", result.rowsAffected, "departureStatus");
}

async function cleanup() {
  console.time("cleanup");
  await Promise.all([vehiclePositions(), departureStatus()]);
  console.timeEnd("cleanup");
}

export async function initCleanup() {
  await cleanup();
  setInterval(cleanup, 1000 * 60 * 2);
}
