import express from "express";
import prisma from "./prisma";

export async function startServer() {
  const app = express();

  app.get("/vehiclePosition/:realtime_trip_id", async (req, res) => {
    const { realtime_trip_id } = req.params;
    const position = await prisma.vehiclePosition.findUnique({
      where: {
        realtime_trip_id,
      },
      select: {
        lat: true,
        lon: true,
        speed: true,
        heading: true,
        received: true,
      },
    });
    if (!position) return res.status(404).end("Not found");
    res.json(position);
  });

  app.get("/departureStatus/:realtime_trip_id", async (req, res) => {
    const { realtime_trip_id } = req.params;
    const departureStatus = await prisma.departureStatus.findUnique({
      where: {
        realtime_trip_id,
      },
      select: {
        stopId: true,
        referNext: true,
        received: true,
      },
    });
    if (!departureStatus) return res.status(404).end("Not found");
    res.json(departureStatus);
  });

  app.listen(3002, () => {
    console.log("Listening on port 3002!");
  });
}
